/* 
 *
 * $Id: k3bmonkeyencoder.h,v 1.1.1.1 2004/03/09 21:34:16 trueg Exp $
 * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
 *
 * This file is part of the K3b project.
 * Copyright (C) 1998-2003 Sebastian Trueg <trueg@k3b.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.
 */

#ifndef _K3B_MONKEY_ENCODER_H_
#define _K3B_MONKEY_ENCODER_H_


#include <k3baudioencoder.h>
#include <k3bpluginconfigwidget.h>

class KInstance;
class QComboBox;


class K3bMonkeyEncoderFactory : public K3bAudioEncoderFactory
{
  Q_OBJECT

 public:
  K3bMonkeyEncoderFactory( QObject* parent = 0, const char* name = 0 );
  ~K3bMonkeyEncoderFactory();

  QStringList extensions() const;
  
  QString fileTypeComment( const QString& ) const;

  long long fileSize( const QString&, const K3b::Msf& msf ) const;

  int pluginSystemVersion() const { return 1; }

  K3bPlugin* createPluginObject( QObject* parent = 0, 
				 const char* name = 0,
				 const QStringList& = QStringList() );
  K3bPluginConfigWidget* createConfigWidgetObject( QWidget* parent = 0, 
						   const char* name = 0,
						   const QStringList &args = QStringList() );

 private:
  KInstance* s_instance;
};


class K3bMonkeyEncoder : public K3bAudioEncoder
{
  Q_OBJECT

 public:
  K3bMonkeyEncoder( QObject* parent = 0, const char* name = 0 );
  ~K3bMonkeyEncoder();

  bool openFile( const QString& extension, const QString& filename );
  bool isOpen() const;
  void closeFile();
  const QString& filename() const;

 private:
  long encodeInternal( const char* data, Q_ULONG len );
  void setMetaDataInternal( MetaDataField, const QString& );

  class Private;
  Private* d;
};


class K3bMonkeyEncoderSettingsWidget : public K3bPluginConfigWidget
{
  Q_OBJECT

 public:
  K3bMonkeyEncoderSettingsWidget( QWidget* parent = 0, const char* name = 0 );
  ~K3bMonkeyEncoderSettingsWidget();

 public slots:
  void loadConfig();
  void saveConfig();

 private:
  QComboBox* m_comboCompressionLevel;
};


K_EXPORT_COMPONENT_FACTORY( libk3bmonkeyencoder, K3bMonkeyEncoderFactory )

#endif
